@@ -1,14 +1,4 @@
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0.
 
 import json
 from enum import Enum
@@ -44,8 +34,9 @@ class Serde:
 
     @classmethod
     def to_dict(cls, obj):
-        dicted = attr.asdict(obj)
-        return cls.remove_nulls_and_enums(dicted)
+        if not isinstance(obj, dict):
+            obj = attr.asdict(obj)
+        return cls.remove_nulls_and_enums(obj)
 
     @classmethod
     def to_json(cls, obj):
